{% if user.is_authenticated %}
    <p>Welcome, {{ user.username }}  <a href="{% url 'logout' %}">[logout]</a></p>
{% else %}
    <p>Welcome, Guest <a href="{% url 'login' %}">[login]</a></p>
{% endif %}
